function [R,Z,f] = CartaRZGaussConv(N,b,c,deltaR,deltaZ,tau0,L)
%function [R,Z,f] = CartaRZGaussConv(N,b,c,deltaR,deltaZ,tau0,L)

%   N:     Numero de puntos a utilizar
%   b:     Hace referencia a la distancia radial maxima del sistema que vamos a estudiar
%   c:     Hace referencia a la altura maxima del cilindro pues ahora se trata de una region finita
%   betaR: Hace referncia al parametro de control de la gaussiana en la direccion radial(R)
%   betaZ: Hace referncia al parametro de control de la gaussiana en la direccion axial(Z)
%   tau0:  Instante en el que voy a considerar el campo escalar de temperaturas.
%   L:     Numero de lineas de contorno que quiero que represente en la grafica en cuestion

%En primer lugar decir, que se tomara un perfil doblemnte gaussiano, tanto en R como en Z, y con un centro situado en el centro del cilindro
%que estamos estudiando y que tendra una altura c y una anchura radial b.

%En el desarrollo de la solucion existen algunos coeficientes que hemos de calcular. Se obtienen con las funciones siguientes:

    [Am,betam] = coefAs(N,deltaR,b);
    etan = raizFun1(N,h,c,H1);
    
    [Q1n,Q2n,etan] = coefQn12(N,deltaZ,c);

%Una vez calculados los coeficientes anteriores, el siguiente paso consiste en calcular la funcion de distribucion de temperaturas

%Inicialicemos las variable a emplear

    B=0;i=1;k=1;D=0;
    
    for Z=0:0.2:c
        
        for n=1:1:N
            D = D + Qn(n)*sin(etan(n)*Z)*exp(-1*tau0*etan(n)^2);
        end
        
        for R=0:0.2:b
        
            for n=1:1:N
                B = B + Am(n)*besselJ(0,betam(n)*R)*exp(-1*tau0*betam(n)^2);
            end
        
            f(k,i) = B*D;
            i=i+1;
            B = 0;
        end
        k = k + 1;
        i=1;
        D = 0;
    end
 
 %Una vez generada la carta devolvamos tambien los datos de R y Z por si se requiere alguna representacion adimensional.
 
    R=0:0.2:b;
    Z=0:0.2:c;
    
    h = contour(R,Z,f,L);
    clabel(h);title('Carta R,Z para Cilindro Finito - Perfil gaussiano en R y Z');        
        
